@@ -25,8 +25,11 @@ def load_json(dest):
 path = "S:/all member/퀀트운용팀/93 QuickDB/"
 
 class QuickDB:
-    def __init__(self, yqtb=None, fsdata=None):
-        self.path = "S:/all member/퀀트운용팀/93 QuickDB/"
+    def __init__(self, yqtb=None, fsdata=None, path=None):
+        if path is None:
+            self.path = "S:/all member/퀀트운용팀/93 QuickDB/"
+        else:
+            self.path = path
         if yqtb is None or fsdata is None:
             self.refresh()
         else:
@@ -35,8 +38,8 @@ class QuickDB:
         
 
     def refresh(self): # daily update하면 refresh 해줘야함.
-        self.yqtb = load_pkl(self.path + 'yq.table')
-        self.fsdata = load_pkl(self.path + 'fsdata.data')
+        self.yqtb = load_pkl(os.path.join(self.path, 'yq.table'))
+        self.fsdata = load_pkl(os.path.join(self.path, 'fsdata.data'))
         
     def getYQ(self, when):
         return self.yqtb.loc[:str(when)].iloc[-1]
@@ -101,12 +104,13 @@ class QuickDB:
             if end:
                 y2 = int(str(end)[:4])
                 for y in range(y1, y2+1):
-                    _ = load_pkl(self.path + f"data/{y}_{n}.data")
+                    _ = load_pkl(os.path.join(self.path, f"data/{y}_{n}.data"))
                     if _ is not None:
                         res.append(_)
                 return pd.concat(res).sort_index().loc[start : end]
             else:
-                return load_pkl(self.path + f'data/{y1}_{n}.data')#.sort_index().drop_duplicates().loc[start:].iloc[0]
+                return load_pkl(os.path.join(self.path, f'data/{y1}_{n}.data'))
+            #.sort_index().drop_duplicates().loc[start:].iloc[0]
         except Exception as e:
             print(e)
             return None
\ No newline at end of file
